@@ -7,8 +7,8 @@
 #' 
 #' Parameters names are searched first in a parameter object
 #' defined with \code{\link{define_parameters}} and linked 
-#' with the matrix through \code{\link{define_model}}; then 
-#' in the environment where the matrix was defined.
+#' with the matrix through \code{\link{define_strategy}};
+#' then in the environment where the matrix was defined.
 #' 
 #' Matric cells are listed by row.
 #' 
@@ -16,7 +16,7 @@
 #' can be conveniently reffered as \code{C}.
 #' 
 #' Only matrix size is checked during this step (the matrix 
-#' must be square). Other conditions (such as rowsums being 
+#' must be square). Other conditions (such as row sums being
 #' equal to 1) are tested later, during model evaluation.
 #' 
 #' For the \code{modify} function existing matrix cells are 
@@ -34,7 +34,7 @@
 #' @param .OBJECT An object of class \code{uneval_matrix}.
 #' @param x An \code{uneval_matrix} to plot.
 #' @param relsize Argument passed to \code{\link{plotmat}}.
-#' @param shadow.size Argument passed to
+#' @param shadow.size Argument passed to 
 #'   \code{\link{plotmat}}.
 #' @param latex Argument passed to \code{\link{plotmat}}.
 #' @param .dots Used to work around non-standard evaluation.
@@ -43,12 +43,9 @@
 #'   a named list of \code{lazy} expressions).
 #' @export
 #' 
-#' @example inst/examples/example_define_matrix.R
+#' @example inst/examples/example_define_transition.R
 #'   
-define_matrix <- function(
-  ...,
-  state_names
-) {
+define_transition <- function(..., state_names) {
   .dots <- lazyeval::lazy_dots(...)
   
   if (missing(state_names)) {
@@ -56,14 +53,11 @@ define_matrix <- function(
     state_names <- LETTERS[seq_len(sqrt(length(lazyeval::lazy_dots(...))))]
   }
   
-  define_matrix_(.dots = .dots, state_names = state_names)
+  define_transition_(.dots = .dots, state_names = state_names)
 }
 
-#' @rdname define_matrix
-define_matrix_ <- function(
-  .dots,
-  state_names
-) {
+#' @rdname define_transition
+define_transition_ <- function(.dots, state_names) {
   
   n <- sqrt(length(.dots))
   
@@ -118,7 +112,7 @@ get_matrix_order.uneval_matrix <- function(x){
 }
 
 #' @export
-#' @rdname define_matrix
+#' @rdname define_transition
 modify.uneval_matrix <- function(.OBJECT, ...){
   
   # !mod!
@@ -141,5 +135,5 @@ modify_.uneval_matrix <- function(.OBJECT, .dots){
     ))
   }
   
-  modifyList(.OBJECT, .dots)
+  utils::modifyList(.OBJECT, .dots)
 }
