@@ -27,8 +27,9 @@
 #'   An optional \code{.weights} column can be included for
 #'   a weighted analysis.
 #' @param x Updated model to plot.
-#' @param model A model index, character or numeric.
-#' @param type The type of plot to return (see details).
+#' @param strategy A model index, character or numeric.
+#' @param result The the result to plot (see details).
+#' @param type Plot simple values or differences?
 #' @param ... Additional arguments passed to
 #'   \code{geom_histogram}. Especially usefull to specify
 #'   \code{binwidth}.
@@ -54,29 +55,30 @@ update.run_model <- function(object, newdata, ...) {
   if (has_weights) {
     weights <- newdata$.weights
     newdata <- dplyr::select_(newdata, ~ (- .weights))
+    
   } else {
-    message("No weights specified in model update, using equal weights.")
+    message("No weights specified in update, using equal weights.")
     weights <- rep(1, nrow(newdata))
   }
   
-  ce <- attr(object, "ce")
+  ce <- get_ce(object)
   list_res <- list()
   
-  for (n in get_model_names(object)) {
-    message(sprintf("Updating model '%s'...", n))
+  for (n in get_strategy_names(object)) {
+    message(sprintf("Updating strategy '%s'...", n))
     suppressMessages({
       list_res <- c(
         list_res,
-        list(eval_model_newdata(object, model = n, 
-                                newdata = newdata))
+        list(eval_strategy_newdata(object, strategy = n, 
+                                   newdata = newdata))
       )
     })
   }
   
-  names(list_res) <- get_model_names(object)
+  names(list_res) <- get_strategy_names(object)
   
   for (n in names(list_res)) {
-    list_res[[n]]$.model_names <- n
+    list_res[[n]]$.strategy_names <- n
     list_res[[n]]$.index <- seq_len(nrow(newdata))
   }
   
@@ -88,116 +90,172 @@ update.run_model <- function(object, newdata, ...) {
       dplyr::do_(~ get_total_state_values(.$.mod)) %>% 
       dplyr::bind_cols(res %>% dplyr::select_(~ - .mod)) %>% 
       dplyr::ungroup() %>% 
-      dplyr::group_by_(".index") %>% 
       dplyr::mutate_(.dots = ce) %>% 
-      dplyr::do_(~ compute_icer(., model_order = order(object$.effect))) %>% 
       dplyr::left_join(
         dplyr::data_frame(
           .index = seq_len(nrow(newdata)),
           .weights = weights
         )
-      )
+      ) %>% 
+      dplyr::ungroup()
   })
   
   comb_mods <- combine_models(
-    list_newmodels = list_res,
+    newmodels = list_res,
     weights = weights,
     oldmodel = object
   )
   
   structure(
-    res_total,
-    class = c("updated_models", class(res)),
-    newdata = newdata,
-    original_model = object,
-    combined_models = comb_mods,
-    has_weights = has_weights,
-    weights = weights
+    list(
+      updated_model = res_total,
+      newdata = newdata,
+      model = object,
+      combined_model = comb_mods,
+      has_weights = has_weights,
+      weights = weights
+    ),
+    class = c("updated_model", class(res))
   )
 }
 
 #' @export
-print.updated_models <- function(x, ...) {
-  print(summary(x, ...))
+print.updated_model <- function(x, ...) {
+  print(summary(x), ...)
 }
 
 #' @export
 #' @rdname update-model
-plot.updated_models <- function(x, model,
-                                type = c("cost", "effect", "icer",
-                                         "counts", "ce", "values"),
-                                ...) {
+plot.updated_model <- function(x, type = c("simple", "difference",
+                                           "counts", "ce", "values"),
+                               result = c("cost", "effect", "icer"),
+                               strategy = NULL,
+                               ...) {
   type <- match.arg(type)
+  result <- match.arg(result)
   
   if (type %in% c("counts", "ce", "values")) {
-    if(missing(model)) model <- "all"
-    return(graphics::plot(attr(x, "combined_models"),
-                          type = type, model = model,
-                          ...) 
-           )
+    return(plot(x$combined_model,
+                type = type, strategy = strategy,
+                ...) 
+    )
+  }
+  if (is.null(strategy)) {
+    strategy <- get_strategy_names(get_model(x))
+    
+    if (type == "difference") {
+      strategy <- setdiff(strategy, get_noncomparable_strategy(get_model(x)))
+    }
+    
+  } else {
+    strategy <- check_strategy_index(
+      get_model(x),
+      strategy,
+      allow_multiple = TRUE
+    )
   }
   
-  check_model_index(
-    attr(x, "original_model"),
-    model,
-    allow_multiple = TRUE
-  )
-  
-  if (get_base_model(attr(x, "original_model")) %in% model) {
-    stop("Cannot represent value differences from base model.")
+  if (get_noncomparable_strategy(get_model(x)) %in% strategy &&
+      "difference" %in% type) {
+    stop("Cannot represent value differences from uncomparable strategy.")
   }
   
-  if (is.numeric(model)) {
-    model <- get_model_names(attr(x, "original_model"))[model]
+  if (type == "simple" && result == "icer") {
+    stop("Result 'icer' can conly be computed with type = 'difference'.")
   }
   
   switch(
-    type,
-    cost = {
-      x_var <- ".dcost"
+    paste(type, result, sep = "_"),
+    simple_cost = {
+      x_var <- ".cost"
       x_lab <- "Cost"
     },
-    effect = {
-      x_var <- ".deffect"
+    simple_effect = {
+      x_var <- ".effect"
       x_lab <- "Effect"
     },
-    icer = {
+    difference_cost = {
+      x_var <- ".dcost"
+      x_lab <- "Cost Diff."
+    },
+    difference_effect = {
+      x_var <- ".deffect"
+      x_lab <- "Effect Diff."
+    },
+    difference_icer = {
       x_var <- ".icer"
       x_lab <- "ICER"
     }
   )
-  
-  res_plot <- (x[x$.model_names %in% model, ]) %>% 
+  summary(x)$scaled_results %>% 
+    dplyr::filter_(
+      substitute(.strategy_names %in% .x, list(.x = strategy))
+    ) %>% 
     ggplot2::ggplot(ggplot2::aes_string(x = x_var)) +
     ggplot2::geom_histogram(...) +
-    ggplot2::xlab(x_lab)
+    ggplot2::xlab(x_lab)+
+    ggplot2::facet_grid(.strategy_names ~ .)
+}
+
+scale.updated_model <- function(x, scale = TRUE, center = TRUE) {
+  .bm <- get_root_strategy(get_model(x))
   
-  if (length(model) > 1) {
-    res_plot <- res_plot +
-      ggplot2::facet_wrap(~ .model_names)
+  res <- x$updated_model
+  
+  if (scale) {
+    res <- res %>% 
+      dplyr::mutate_(
+        .cost = ~ .cost / sum(get_init(get_model(x))),
+        .effect = ~ .effect / sum(get_init(get_model(x)))
+      )
   }
   
-  res_plot
+  if (center) {
+    res <- res %>% 
+      dplyr::group_by_(".index") %>% 
+      dplyr::mutate_(
+        .cost = ~ (.cost - sum(.cost * (.strategy_names == .bm))),
+        .effect = ~ (.effect - sum(.effect * (.strategy_names == .bm)))
+      ) %>% 
+      dplyr::ungroup()
+  }
+  
+  res
+}
+
+get_model.updated_model <- function(x) {
+  x$model
 }
 
 #' @export
-summary.updated_models <- function(object, ...) {
+summary.updated_model <- function(object, ...) {
   
-  model_names <- get_model_names(
-    attr(object, "original_model")
-  )[order(attr(object, "original_model")$.effect)]
+  strategy_names <- get_strategy_names(
+    get_model(object)
+  )[ord_eff <- order(get_effect(get_model(object)))]
   
   list_res <- list()
   
-  for (n in model_names) {
+  tab_scaled <- object %>% 
+    scale(center = FALSE) %>% 
+    dplyr::group_by_(".index") %>% 
+    dplyr::do_(~ compute_icer(
+      ., strategy_order = ord_eff)
+    )
+  
+  for (.n in strategy_names) {
+    
+    tmp <- tab_scaled %>%
+      dplyr::filter_(~ .strategy_names == .n)
+    
     list_res <- c(
       list_res,
       lapply(
         c(".cost", ".effect", ".dcost", ".deffect", ".icer"),
         function(x) {
           wsum <- wtd_summary(
-            object[object$.model_names == n, ][[x]],
-            object[object$.model_names == n, ]$.weights
+            tmp[[x]],
+            tmp$.weights
           )
           is.na(wsum) <- ! is.finite(wsum)
           tab_summary <- matrix(
@@ -206,7 +264,7 @@ summary.updated_models <- function(object, ...) {
           )
           colnames(tab_summary) <- names(wsum)
           cbind(
-            data.frame(Model = n,
+            data.frame(Model = .n,
                        Value = x),
             tab_summary
           )
@@ -232,44 +290,52 @@ summary.updated_models <- function(object, ...) {
     ~ (- Model),
     ~ (- Value)
   ) %>% 
-    as.matrix
+    as.matrix()
   
   rownames(mat_res) <- tab_res$Model %>% 
     paste(tab_res$Value, sep = " - ")
   
   structure(
-    tab_res,
-    class = c("summary_updated_models", class(tab_res)),
-    model = object,
-    to_print = mat_res
+    list(
+      summary_results = tab_res,
+      scaled_results = tab_scaled,
+      model = object,
+      to_print = mat_res,
+      sum_comb = summary(object$combined_model, ...)
+    ),
+    class = c("summary_updated_model", class(tab_res))
   )
 }
 
+get_model.summary_updated_model <- function(x) {
+  x$model
+}
+
 #' @export
-print.summary_updated_models <- function(x, ...) {
-  object <- attr(x, "model")
+print.summary_updated_model <- function(x, ...) {
+  object <- get_model(x)
   
   cat(sprintf(
     "An analysis re-run on %i parameter sets.\n\n",
-    nrow(attr(object, "newdata"))
+    nrow(object$newdata)
   ))
   
-  if (! attr(object, "has_weights")) {
+  if (! object$has_weights) {
     cat("* Unweighted analysis.")
   } else {
     cat("* Weigths distribution:\n\n")
-    print(summary(attr(object, "weights")))
+    print(summary(object$weights))
     cat(sprintf("\nTotal weight: %s",
-                format(sum(attr(object, "weights")))))
+                format(sum(object$weights))))
   }
   
   cat("\n\n* Values distribution:\n\n")
   
-  print(attr(x, "to_print"), na.print = "-")
+  print(x$to_print, na.print = "-")
   
   cat("\n* Combined result:\n\n")
   
-  print(attr(object, "combined_models"))
+  print(x$sum_comb)
   
   invisible(x)
 }
