@@ -99,54 +99,41 @@ test_that(
       effect = y,
       method = "beginning"
     )
-    expect_output(
-      str(e_mod),
-      '1 obs. of  5 variables:
- $ x           : num 1593
- $ y           : num 1515
- $ .model_names: chr "I"
- $ .cost       : num 1593
- $ .effect     : num 1515',
-      fixed = TRUE
+    expect_equal(
+      round(e_mod$run_model$x), 1593
     )
-    expect_output(
-      print(e_mod),
-      "   N
-X1 1
-X2 0
-
-Counting method: 'beginning'.
-
-         x        y
-I 1592.538 1514.507",
-      fixed = TRUE
+    expect_equal(
+      round(e_mod$run_model$y), 1515
+    )
+    expect_equal(
+      e_mod$run_model$.strategy_names, "I"
+    )
+    expect_equal(
+      round(e_mod$run_model$.cost), 1593
+    )
+    expect_equal(
+      round(e_mod$run_model$.effect), 1515
+    )
+    expect_equivalent(
+      heemod:::get_init(e_mod),
+      c(1, 0)
     )
     
     s_mod <- summary(e_mod)
-    expect_length(
-      s_mod, 6
+    expect_equal(
+      round(s_mod$res_values$x), 1593
     )
-    expect_identical(
-      dim(s_mod$res), c(1L, 2L)
+    expect_equal(
+      round(s_mod$res_values$y), 1515
     )
-    expect_identical(
-      round(s_mod$res$x),  1593
+    expect_equal(
+      s_mod$res_values$.strategy_names, "I"
     )
-    expect_identical(
-      round(s_mod$res$y), 1515
-    )
-    expect_output(
-      print(summary(e_mod)),
-      "   N
-X1 1
-X2 0
-
-Counting method: 'beginning'.
-
-         x        y
-I 1592.538 1514.507",
-      fixed = TRUE
+    
+    expect_equal(
+      nrow(s_mod$res_comp), 1
     )
+    
     expect_error(
       run_model(
         mod1,
@@ -212,54 +199,40 @@ test_that(
       effect = y,
       method = "beginning"
     )
-    expect_output(
-      str(e_mod2),
-      '2 obs. of  5 variables:
- $ x           : num  1593 1170
- $ y           : num  1515 615
- $ .model_names: chr  "I" "II"
- $ .cost       : num  1593 1170
- $ .effect     : num  1515 615',
-      fixed = TRUE
+    
+    expect_equal(
+      round(e_mod2$run_model$x), c(1593, 1170)
     )
-    expect_output(
-      print(e_mod2),
-      "422.5384     899.5074 0.4697442",
-      fixed = TRUE
+    expect_equal(
+      round(e_mod2$run_model$y), c(1515, 615)
     )
-    s_mod2 <- summary(e_mod2)
-    expect_length(
-      s_mod2, 6
+    expect_equal(
+      e_mod2$run_model$.strategy_names, c("I", "II")
     )
-    expect_identical(
-      dim(s_mod2$res), c(2L, 2L)
+    expect_equal(
+      round(e_mod2$run_model$.cost), c(1593, 1170)
     )
-    expect_identical(
-      round(s_mod2$res$x), c(1170, 1593)
+    expect_equal(
+      round(e_mod2$run_model$.effect), c(1515, 615)
     )
-    expect_identical(
-      round(s_mod2$res$y), c(615, 1515)
+    expect_equivalent(
+      heemod:::get_init(e_mod2),
+      c(1, 0)
     )
     
-    expect_output(
-      print(summary(e_mod2)),
-      "422.5384     899.5074 0.4697442",
-      fixed = TRUE
+    s_mod2 <- summary(e_mod2)
+    expect_equal(
+      round(s_mod2$res_values$x),  c(1593, 1170)
     )
-    expect_output(
-      print(
-        run_model(
-          mod1 = mod1, mod2 = mod2,
-          parameters = par1,
-          init = c(1, 0),
-          cycles = 5,
-          cost = x,
-          effect = y,
-          method = "beginning"
-        )
-      ),
-      "422.5384     899.5074 0.4697442",
-      fixed = TRUE
+    expect_equal(
+      round(s_mod2$res_values$y), c(1515, 615)
+    )
+    expect_equal(
+      s_mod2$res_values$.strategy_names, c("I", "II")
+    )
+    
+    expect_equal(
+      nrow(s_mod2$res_comp), 2
     )
   }
 )
